@@ -28,7 +28,9 @@ class ValidationError(Enum):
     CONTENT_EXPECTED_TIME_FORMAT = auto()
     CONTENT_EXPECTED_URI = auto()
     CONTENT_EXPECTED_YEAR_FORMAT = auto()
+    MAX_CHOICE_EXCEEDED = auto()
     MAX_OCCURRENCE_EXCEEDED = auto()
+    MIN_CHOICE_UNMET = auto()
     MIN_OCCURRENCE_UNMET = auto()
     STR_CONTENT_UNICODE_ERROR = auto()
     UNKNOWN_ATTRIBUTE = auto()
